@@ -13,7 +13,7 @@ from typing import List
 from pydantic import BaseModel
 
 from ValidationRules.ruleHandler import RuleHandler
-from ValidationRules.structureFunc import doubleWrap
+from ValidationRules.structureFunc import doubleWrap, isNotEmptyString
 
 
 class StringRules(BaseModel):
@@ -38,18 +38,19 @@ class StringRules(BaseModel):
             :param kwargs:
             :return:
             """
-            account_list: List[str] = [str(account) for account in args if type(account) == str]
+            account_list: List[str] = [str(account) for account in args if
+                                       type(account) == str and isNotEmptyString(account)]
             if required and not account_list:
-                raise ValueError("label {} value {} is not allowed value,check input".format(label,account_list))
+                raise ValueError("label {} value {} is not allowed value,check input".format(label, account_list))
             for account_str in account_list:
-                RuleHandler.checkAccount(account_str,label=label,error_msg=error_msg)
+                RuleHandler.checkAccount(account_str, label=label, error_msg=error_msg)
             return func(*args, **kwargs)
 
         return checkAccount
 
     @staticmethod
     @doubleWrap
-    def mobileRule(func, required: bool = False, label: str = "手机号",error_msg: str = ""):
+    def mobileRule(func, required: bool = False, label: str = "手机号", error_msg: str = ""):
         """
         标准手机号校验
         :param error_msg: 错误信息自定义，默认空
@@ -67,12 +68,14 @@ class StringRules(BaseModel):
             :param kwargs:
             :return:
             """
-            mobile_str_list: List[str] = [str(mobile) for mobile in args if type(mobile) == str or type(mobile) == int]
+            mobile_str_list: List[str] = [str(mobile) for mobile in args if
+                                          type(mobile) == str and isNotEmptyString(mobile) or type(mobile) == int]
+            print(mobile_str_list)
             if required and not mobile_str_list:
-                raise ValueError("label {} value {} is not allowed value,check input".format(label,mobile_str_list))
+                raise ValueError("label {} value {} is not allowed value,check input".format(label, mobile_str_list))
 
             for mobile_str in mobile_str_list:
-                RuleHandler.checkMobile(mobile_str,label=label,error_msg=error_msg)
+                RuleHandler.checkMobile(mobile_str, label=label, error_msg=error_msg)
             return func(*args, **kwargs)
 
         return checkMobile
@@ -81,7 +84,7 @@ class StringRules(BaseModel):
     @doubleWrap
     def keywordCheckRule(func, keyword_list: List[str] = None, startswith: str = None, endswith: str = None,
                          min_length: int = None, max_length: int = None, password_level: int = 0,
-                         required: bool = False, label: str = "字符",error_msg: str = ""):
+                         required: bool = False, label: str = "字符", error_msg: str = ""):
         """
         输入字符验证
         :param error_msg: 错误信息自定义，默认空
@@ -99,21 +102,22 @@ class StringRules(BaseModel):
 
         @wraps(func)
         def checkKeyword(*args, **kwargs):
-            verified_str_list: List[str] = [str(verified_str) for verified_str in args if type(verified_str) == str]
+            verified_str_list: List[str] = [str(verified_str) for verified_str in args if
+                                            type(verified_str) == str and isNotEmptyString(verified_str)]
             if required and not verified_str_list:
-                raise ValueError("label {} value {} is not allowed value,check input".format(label,verified_str_list))
+                raise ValueError("label {} value {} is not allowed value,check input".format(label, verified_str_list))
             for verified_str in verified_str_list:
                 RuleHandler.checkPassword(verified_str, keyword_list=keyword_list, startswith=startswith,
                                           endswith=endswith, min_length=min_length,
                                           max_length=max_length,
-                                          password_level=password_level,label=label,error_msg=error_msg)
+                                          password_level=password_level, label=label, error_msg=error_msg)
             return func(*args, *kwargs)
 
         return checkKeyword
 
     @staticmethod
     @doubleWrap
-    def emailRule(func, required: bool = False, label: str = "邮箱",error_msg: str = None):
+    def emailRule(func, required: bool = False, label: str = "邮箱", error_msg: str = None):
         """
         标准邮箱校验
         :param error_msg: 错误信息自定义，默认空
@@ -125,18 +129,19 @@ class StringRules(BaseModel):
 
         @wraps(func)
         def checkEmail(*args, **kwargs):
-            email_str_list = [str(email_str) for email_str in args if type(email_str) == str]
+            email_str_list = [str(email_str) for email_str in args if
+                              type(email_str) == str and isNotEmptyString(email_str)]
             if required and not email_str_list:
-                raise ValueError("label {} value {} is not allowed value,check input".format(label,email_str_list))
+                raise ValueError("label {} value {} is not allowed value,check input".format(label, email_str_list))
             for email_str in email_str_list:
-                RuleHandler.checkEmail(email_str,label=label,error_msg=error_msg)
+                RuleHandler.checkEmail(email_str, label=label, error_msg=error_msg)
             return func(*args, **kwargs)
 
         return checkEmail
 
     @staticmethod
     @doubleWrap
-    def IDCardRule(func, required: bool = False, label: str = "身份证",error_msg: str = None):
+    def IDCardRule(func, required: bool = False, label: str = "身份证", error_msg: str = None):
         """
         身份证号校验
         :param error_msg: 错误信息自定义，默认空
@@ -154,11 +159,11 @@ class StringRules(BaseModel):
             :param kwargs:
             :return:
             """
-            id_str_list = [str(id_str) for id_str in args if type(id_str) == str]
+            id_str_list = [str(id_str) for id_str in args if type(id_str) == str and isNotEmptyString(id_str)]
             if required and not id_str_list:
-                raise ValueError("label {} value {} is not allowed value,check input".format(label,id_str_list))
+                raise ValueError("label {} value {} is not allowed value,check input".format(label, id_str_list))
             for id_str in id_str_list:
-                RuleHandler.checkIDCard(id_str,label=label,error_msg=error_msg)
+                RuleHandler.checkIDCard(id_str, label=label, error_msg=error_msg)
             return func(*args, **kwargs)
 
         return checkIDCard
