@@ -23,3 +23,9 @@ def doubleWrap(func):
             return lambda real_func: func(real_func, *args, **kwargs)
 
     return new_dec
+
+
+def isNotEmptyString(value):
+    if value and value != '' and value != "":
+        return True
+    return False
